package net.sourceforge.nattable.data.convert;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.layer.cell.LayerCell;

/**
 * Converts between two different data representations.
 *
 * The normal data representation is known as the <i>canonical representation</i>
 * The representation displayed on the UI is called the <i>display representation</i>.
 *
 * For example, the canonical representation might be a Date object,
 * whereas the target representation could be a formatted String.
 */
public interface IDisplayConverter {

	/**
	 * Convert backing data value -> value to be displayed<br/>
	 * Typically converted to a String for display.
	 */
	public Object canonicalToDisplayValue(Object canonicalValue);

	/**
	 * Convert from display value -> value in the backing data structure<br/>
	 * NOTE: The type the display value is converted to <i>must</i> match the type
	 * in the setter of the backing bean/row object
	 */
	public Object displayToCanonicalValue(Object displayValue);

	/**
	 * Convert backing data value -> value to be displayed<br/>
	 * Typically converted to a String for display.
	 * Use this method for contextual conversion.
	 */
	public Object canonicalToDisplayValue(LayerCell cell, IConfigRegistry configRegistry, Object canonicalValue);
	
	/**
	 * Convert from display value -> value in the backing data structure<br/>
	 * NOTE: The type the display value is converted to <i>must</i> match the type
	 * in the setter of the backing bean/row object
	 * Use this method for contextual conversion.
	 */
	public Object displayToCanonicalValue(LayerCell cell, IConfigRegistry configRegistry, Object displayValue);
}
