package net.sourceforge.nattable.edit.config;

import net.sourceforge.nattable.config.AbstractLayerConfiguration;
import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.config.IEditableRule;
import net.sourceforge.nattable.data.validate.DefaultDataValidator;
import net.sourceforge.nattable.edit.EditConfigAttributes;
import net.sourceforge.nattable.edit.command.EditCellCommandHandler;
import net.sourceforge.nattable.edit.editor.TextCellEditor;
import net.sourceforge.nattable.edit.event.InlineCellEditEventHandler;
import net.sourceforge.nattable.grid.layer.GridLayer;
import net.sourceforge.nattable.style.CellStyleAttributes;
import net.sourceforge.nattable.style.DisplayMode;
import net.sourceforge.nattable.style.IStyle;
import net.sourceforge.nattable.style.Style;
import net.sourceforge.nattable.util.GUIHelper;

public class DefaultEditConfiguration extends AbstractLayerConfiguration<GridLayer> {

	@Override
	public void configureTypedLayer(GridLayer gridLayer) {
		gridLayer.registerCommandHandler(new EditCellCommandHandler());
		gridLayer.registerEventHandler(new InlineCellEditEventHandler(gridLayer));
	}
	
	@Override
	public void configureRegistry(IConfigRegistry configRegistry) {
		configRegistry.registerConfigAttribute(EditConfigAttributes.CELL_EDITABLE_RULE, IEditableRule.NEVER_EDITABLE);
		configRegistry.registerConfigAttribute(EditConfigAttributes.CELL_EDITOR, new TextCellEditor());
		configRegistry.registerConfigAttribute(EditConfigAttributes.DATA_VALIDATOR, new DefaultDataValidator());
		
//		configRegistry.registerConfigAttribute(EditConfigAttributes.ERROR_HANDLING, new DialogErrorHandlingStrategy());
		
		IStyle validationErrorStyle = new Style();
		validationErrorStyle.setAttributeValue(CellStyleAttributes.FOREGROUND_COLOR, GUIHelper.COLOR_RED);
		configRegistry.registerConfigAttribute(EditConfigAttributes.VALIDATION_ERROR_STYLE, validationErrorStyle, DisplayMode.NORMAL, EditStyleLabels.VALIDATION_ERROR_STYLE);
		configRegistry.registerConfigAttribute(EditConfigAttributes.VALIDATION_ERROR_STYLE, validationErrorStyle, DisplayMode.NORMAL, EditStyleLabels.VALIDATION_ERROR_STYLE);
	}
	
}
