package net.sourceforge.nattable.filterrow;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.data.IDataProvider;
import net.sourceforge.nattable.grid.GridRegion;
import net.sourceforge.nattable.grid.layer.ColumnHeaderLayer;
import net.sourceforge.nattable.grid.layer.DimensionallyDependentLayer;
import net.sourceforge.nattable.layer.CompositeLayer;
import net.sourceforge.nattable.layer.DataLayer;
import net.sourceforge.nattable.layer.ILayer;

/**
 * 1 column x 2 rows Composite layer<br/>
 * - First row is the {@link ColumnHeaderLayer}<br/>
 * - Second row is the composite is the filter row layer. The filter row layer is a {@link DimensionallyDependentLayer}
 * 		dependent on the {@link ColumnHeaderLayer}
 *
 * @see FilterRowDataLayer
 */
public class FilterRowHeaderComposite<T> extends CompositeLayer {

	public FilterRowHeaderComposite(IFilterStrategy<T> filterStrategy, ILayer columnHeaderLayer, IDataProvider columnHeaderDataProvider, IConfigRegistry configRegistry) {
		super(1, 2);

		setChildLayer("columnHeader", columnHeaderLayer, 0, 0);

		final DataLayer filterRowDataLayer = new FilterRowDataLayer<T>(filterStrategy, columnHeaderLayer, columnHeaderDataProvider, configRegistry);
		DimensionallyDependentLayer filterRowLayer = new DimensionallyDependentLayer(filterRowDataLayer, columnHeaderLayer, filterRowDataLayer);

		setChildLayer(GridRegion.FILTER_ROW, filterRowLayer, 0, 1);
	}

}