package net.sourceforge.nattable.filterrow;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.edit.EditConfigAttributes;
import net.sourceforge.nattable.edit.editor.ComboBoxCellEditor;
import net.sourceforge.nattable.edit.editor.ICellEditor;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.painter.cell.CellPainterWrapper;
import net.sourceforge.nattable.painter.cell.ImagePainter;
import net.sourceforge.nattable.painter.cell.TextPainter;
import net.sourceforge.nattable.painter.cell.decorator.CellPainterDecorator;
import net.sourceforge.nattable.painter.cell.decorator.PaddingDecorator;
import net.sourceforge.nattable.ui.util.CellEdgeEnum;
import net.sourceforge.nattable.util.GUIHelper;
import net.sourceforge.nattable.util.ObjectUtils;

import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Rectangle;

public class FilterRowPainter extends CellPainterWrapper {

	private final FilterIconPainter filterIconPainter;
	private final int TOP_IMAGE_PADDING = 2;
	private final int RIGHT_IMAGE_PADDING = 0;
	
	public FilterRowPainter() {
		filterIconPainter = new FilterIconPainter();
		setWrappedPainter(new CellPainterDecorator(new TextPainter(), CellEdgeEnum.RIGHT, new PaddingDecorator(
				filterIconPainter,
				TOP_IMAGE_PADDING,
				RIGHT_IMAGE_PADDING,
				0,
				0)));
	}
	
	public boolean containsRemoveFilterImage(int x, int y, LayerCell cell, IConfigRegistry configRegistry) {
		Image image = filterIconPainter.getImage(cell, configRegistry);
		if (image == null) {
			return false;
		}
		int iconImageWidth = image.getImageData().width;
		int iconImageHeight = image.getImageData().height;
		Rectangle cellBounds = cell.getBounds();
		Rectangle imageBounds = new Rectangle(
				cellBounds.x + cellBounds.width - RIGHT_IMAGE_PADDING - iconImageWidth,
				cellBounds.y + TOP_IMAGE_PADDING,
				iconImageWidth,
				iconImageHeight).intersection(cellBounds);
		return imageBounds.contains(x, y);
	}
	
	static class FilterIconPainter extends ImagePainter {

		@Override
		protected Image getImage(LayerCell cell, IConfigRegistry configRegistry) {
			// If a filter value is present draw the remove filter icon 
			if(ObjectUtils.isNotNull(cell.getDataValue())){
				return GUIHelper.getImage("remove_filter");
			}
			
			ICellEditor cellEditor = configRegistry.getConfigAttribute(
					EditConfigAttributes.CELL_EDITOR, cell.getDisplayMode(), cell.getConfigLabels().getLabels());
			
			// If a comb box is specified as the editor, draw the combo box arrow 
			if (ObjectUtils.isNotNull(cellEditor) && cellEditor instanceof ComboBoxCellEditor) {
				return GUIHelper.getImage("down_2");
			}

			return null;
		}
	}
}
