package net.sourceforge.nattable.group;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.group.model.IRowGroup;
import net.sourceforge.nattable.group.model.IRowGroupModel;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.painter.cell.CellPainterWrapper;
import net.sourceforge.nattable.painter.cell.ICellPainter;
import net.sourceforge.nattable.painter.cell.ImagePainter;
import net.sourceforge.nattable.painter.cell.TextPainter;
import net.sourceforge.nattable.painter.cell.decorator.CellPainterDecorator;
import net.sourceforge.nattable.ui.util.CellEdgeEnum;
import net.sourceforge.nattable.util.GUIHelper;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Image;

public class RowGroupHeaderTextPainter<T> extends CellPainterWrapper {

	/** Needed to query row group cell expand/collapse state */
	private final IRowGroupModel<T> rowGroupModel;
	
	public RowGroupHeaderTextPainter(IRowGroupModel<T> rowGroupModel) {
		this.rowGroupModel = rowGroupModel;
				
		setWrappedPainter(new CellPainterDecorator(new TextPainter(), CellEdgeEnum.BOTTOM, new ExpandCollapseImagePainter()));
	}
	
	/**
	 * @param rowGroupModel Column group model used by the grid
	 * @param interiorPainter for painting the text portion
	 * @param imagePainter for painting the icon image on the right
	 */
	public RowGroupHeaderTextPainter(IRowGroupModel<T> rowGroupModel, ICellPainter interiorPainter) {
		this.rowGroupModel = rowGroupModel;
		setWrappedPainter(new CellPainterDecorator(interiorPainter, CellEdgeEnum.BOTTOM, new ExpandCollapseImagePainter()));
	}
	
	@Override
	public int getPreferredWidth(LayerCell cell, GC gc, IConfigRegistry configRegistry) {
		return 0;
	}

	public class ExpandCollapseImagePainter extends ImagePainter {
		final Image downImg = GUIHelper.getImage("down_0"); //$NON-NLS-1$
		final Image upImg = GUIHelper.getImage("up_0"); //$NON-NLS-1$

		public ExpandCollapseImagePainter() {
			super(null, true);
		}

		@Override
		protected Image getImage(LayerCell cell, IConfigRegistry configRegistry) {
			final IRowGroup<T> rowGroup = RowGroupUtils.getTopMostParentGroup(RowGroupUtils.getRowGroupForRowIndex(RowGroupHeaderTextPainter.this.rowGroupModel, cell.getRowIndex()));
			
			if (rowGroup != null) {
				return rowGroup.isCollapsed() ? downImg : upImg;
			} else {
				return null;
			}
		}
	}
}
