package net.sourceforge.nattable.group.config;

import net.sourceforge.nattable.config.CellConfigAttributes;
import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.config.IConfiguration;
import net.sourceforge.nattable.grid.GridRegion;
import net.sourceforge.nattable.group.RowGroupHeaderTextPainter;
import net.sourceforge.nattable.group.action.RowGroupExpandCollapseAction;
import net.sourceforge.nattable.group.model.IRowGroupModel;
import net.sourceforge.nattable.layer.ILayer;
import net.sourceforge.nattable.painter.cell.decorator.BeveledBorderDecorator;
import net.sourceforge.nattable.selection.action.SelectRowGroupsAction;
import net.sourceforge.nattable.style.DisplayMode;
import net.sourceforge.nattable.ui.action.IMouseAction;
import net.sourceforge.nattable.ui.binding.UiBindingRegistry;
import net.sourceforge.nattable.ui.matcher.MouseEventMatcher;

import org.eclipse.swt.SWT;

public class DefaultRowGroupHeaderLayerConfiguration<T> implements IConfiguration {

	private final IRowGroupModel<T> rowGroupModel;
	
	public DefaultRowGroupHeaderLayerConfiguration(final IRowGroupModel<T> rowGroupModel) {
		this.rowGroupModel = rowGroupModel;
	}
	
	public void configureLayer(ILayer layer) {
		// No op
	}

	public void configureRegistry(IConfigRegistry configRegistry) {
		configRegistry.registerConfigAttribute(
				CellConfigAttributes.CELL_PAINTER,
				new BeveledBorderDecorator(new RowGroupHeaderTextPainter<T>(rowGroupModel)),
				DisplayMode.NORMAL,
				GridRegion.ROW_GROUP_HEADER
		);
	}

	public void configureUiBindings(UiBindingRegistry uiBindingRegistry) {
		
		final IMouseAction action = new SelectRowGroupsAction();
		uiBindingRegistry.registerSingleClickBinding(MouseEventMatcher.rowGroupHeaderLeftClick(SWT.NONE), action);
		uiBindingRegistry.registerSingleClickBinding(MouseEventMatcher.rowGroupHeaderLeftClick(SWT.CTRL), action);
		uiBindingRegistry.registerSingleClickBinding(MouseEventMatcher.rowGroupHeaderLeftClick(SWT.SHIFT), action);
		
		uiBindingRegistry.registerDoubleClickBinding(
				MouseEventMatcher.rowGroupHeaderLeftClick(SWT.NONE),
				new RowGroupExpandCollapseAction());
	}

}
