package net.sourceforge.nattable.painter.cell;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.layer.cell.LayerCell;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Rectangle;

public abstract class CellPainterWrapper extends AbstractCellPainter {

	private ICellPainter wrappedPainter;

	public CellPainterWrapper() {}

	public CellPainterWrapper(ICellPainter painter) {
		this.wrappedPainter = painter;
	}

	public void setWrappedPainter(ICellPainter painter) {
		this.wrappedPainter = painter;
	}

	public ICellPainter getWrappedPainter() {
		return wrappedPainter;
	}

	public Rectangle getWrappedPainterBounds(Rectangle adjustedCellBounds) {
		return adjustedCellBounds;
	}

	@Override
	public ICellPainter getCellPainterAt(int x, int y, LayerCell cell, GC gc, Rectangle adjustedCellBounds, IConfigRegistry configRegistry) {
		if (wrappedPainter != null && getWrappedPainterBounds(adjustedCellBounds).contains(x, y)) {
			return getWrappedPainter().getCellPainterAt(x, y, cell, gc, adjustedCellBounds, configRegistry);
		} else {
			return super.getCellPainterAt(x, y, cell, gc, adjustedCellBounds, configRegistry);
		}
	}
	
	public int getPreferredWidth(LayerCell cell, GC gc, IConfigRegistry configRegistry) {
		return wrappedPainter != null ? wrappedPainter.getPreferredWidth(cell, gc, configRegistry) : 0;
	}

	public int getPreferredHeight(LayerCell cell, GC gc, IConfigRegistry configRegistry) {
		return wrappedPainter != null ? wrappedPainter.getPreferredHeight(cell, gc, configRegistry) : 0;
	}

	public void paintCell(LayerCell cell, GC gc, Rectangle adjustedCellBounds, IConfigRegistry configRegistry) {
		if (wrappedPainter != null) {
			wrappedPainter.paintCell(cell, gc, adjustedCellBounds, configRegistry);
		}
	}

}
