package net.sourceforge.nattable.painter.layer;

import net.sourceforge.nattable.NatTable;
import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.layer.ILayer;
import net.sourceforge.nattable.painter.IOverlayPainter;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Rectangle;

public class NatLayerPainter implements ILayerPainter {

	private final NatTable natTable;

	public NatLayerPainter(NatTable natTable) {
		this.natTable = natTable;
	}
	
	public void paintLayer(ILayer natLayer, GC gc, int xOffset, int yOffset, Rectangle rectangle, IConfigRegistry configRegistry) {
		try {
			paintBackground(natLayer, gc, xOffset, yOffset, rectangle, configRegistry);
			
			gc.setForeground(natTable.getForeground());

			ILayerPainter layerPainter = natTable.getLayer().getLayerPainter();
			layerPainter.paintLayer(natLayer, gc, xOffset, yOffset, rectangle, configRegistry);

			paintOverlays(natLayer, gc, xOffset, yOffset, rectangle, configRegistry);
		} catch (Exception e) {
			e.printStackTrace(System.err);
			System.err.println("Error while painting table: " + e.getMessage()); //$NON-NLS-1$
		}
	}
	
	protected void paintBackground(ILayer natLayer, GC gc, int xOffset, int yOffset, Rectangle rectangle, IConfigRegistry configRegistry) {
		gc.setBackground(natTable.getBackground());

		// Clean Background
		gc.fillRectangle(rectangle);
	}
	
	protected void paintOverlays(ILayer natLayer, GC gc, int xOffset, int yOffset, Rectangle rectangle, IConfigRegistry configRegistry) {
		for (IOverlayPainter overlayPainter : natTable.getOverlayPainters()) {
			overlayPainter.paintOverlay(gc, natTable);
		}
	}

	public Rectangle adjustCellBounds(Rectangle cellBounds) {
		ILayerPainter layerPainter = natTable.getLayer().getLayerPainter();
		return layerPainter.adjustCellBounds(cellBounds);
	}

}
