package net.sourceforge.nattable.tree.config;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.export.excel.DefaultExportFormatter;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.tree.ITreeRowModel;

public class TreeExportFormatter extends DefaultExportFormatter {

	private final ITreeRowModel<?> treeRowModel;
	
	public TreeExportFormatter(ITreeRowModel<?> treeRowModel) {
		this.treeRowModel = treeRowModel;
	}
	
	@Override
	public Object formatForExport(LayerCell cell, IConfigRegistry configRegistry) {
		int index = cell.getLayer().getRowIndexByPosition(cell.getRowPosition());
		int depth = treeRowModel.depth(index);
		
		StringBuilder str = new StringBuilder();
		if (depth > 0) {
			for (int i = 0; i < depth; i++) {
				str.append("  ");
			}
		}
		
		if (treeRowModel.isLeaf(index)) {
			str.append(super.formatForExport(cell, configRegistry));
		} else {
			str.append(treeRowModel.getObjectAtIndexAndDepth(index, depth));
		}
		
		return str.toString();
	}
	
}
